<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:AssetsOther']">
  <xsl:variable name="title" select="'Other Property'"/>
  <tr><td colspan="3"><xsl:value-of select="$title"/></td></tr>
  <xsl:apply-templates select="group"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:AssetsOther']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:AssetsOther.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top">
    <xsl:call-template name="AssetsOther.Row.start"/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:AssetsOther.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="row_timestamps" />
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:AssetsOther.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:AssetsOther.Row']/item[1]">

  <xsl:variable name="Ownership"     select="../item[@type='ownership']"/>
  <xsl:variable name="Asset"         select="../item[@type='asset']"/>
  <xsl:variable name="Description"   select="../item[@type='description']"/>
  <xsl:variable name="IsInProgress"  select="../item[@type='is.in.progress']"/>
  <xsl:variable name="Quantity"      select="../item[@type='quantity']"/>
  <xsl:variable name="IsQuantityEst" select="../item[@type='is.quantity.est']"/>
  <xsl:variable name="SizeAmnt"      select="../item[@type='size/amnt']"/>
  <xsl:variable name="Unit"          select="../item[@type='unit']"/>
  <xsl:variable name="IsSizeAmntEst" select="../item[@type='is.size/amnt.est']"/>
  <xsl:variable name="Value"         select="../item[@type='value']"/>
  <xsl:variable name="Currency"      select="../item[@type='currency']"/>
  <xsl:variable name="IsValueEst"    select="../item[@type='is.value.est']"/>
  <xsl:variable name="Name"          select="../item[@type='name']"/>
  <xsl:variable name="Igkno"         select="../item[@type='igkno']"/>
  <xsl:variable name="Country"       select="../item[@type='addr.country']"/>
  <xsl:variable name="City"          select="../item[@type='addr.city']"/>
  <xsl:variable name="Zip"           select="../item[@type='addr.zip']"/>
  <xsl:variable name="Address"       select="../item[@type='addr.address']"/>

<tr valign="top">
  <xsl:call-template name="AssetsOther.Row.start"/>
  <td>
    <table cellSpacing="0" cellPadding="0" width="95%">
      <colgroup>
<col width="110"/>
<col width="10"/>
<col width="380"/>
      </colgroup>
      <tr valign="top">
        <td colspan="3">
<i>
          <xsl:if test="$Ownership = 'n/a'">
            <xsl:text>ownership </xsl:text> 
          </xsl:if>
          <xsl:value-of select="$Ownership"/>: </i>
          <xsl:value-of select="$Asset"/>
          <xsl:text> </xsl:text> 
          <xsl:if test="$IsInProgress = 'true'">
<i>(in progress)</i>
          </xsl:if>
          <xsl:if test="$Description">
            <xsl:text> - </xsl:text> 
            <xsl:value-of select="$Description"/>
          </xsl:if>
        </td>
      </tr>

    <xsl:if test="$Quantity">
      <tr valign="top">
        <td align="right">quantity</td><td> : </td>
        <td>
          <xsl:value-of select="$Quantity"/> unit(s)
          <xsl:if test="$IsQuantityEst = 'true'">
            <xsl:text> </xsl:text>
            <xsl:text>[E]</xsl:text>
          </xsl:if>
        </td>
      </tr>
    </xsl:if>

    <xsl:if test="$SizeAmnt">
      <tr valign="top">
        <td align="right">size/amount</td><td> : </td>
        <td>
          <xsl:value-of select="$SizeAmnt"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="$Unit"/>
          <xsl:if test="$IsSizeAmntEst = 'true'">
            <xsl:text> </xsl:text>
            <xsl:text>[E]</xsl:text>
          </xsl:if>
        </td>
      </tr>
    </xsl:if>

    <xsl:if test="$Value">
      <tr valign="top">
        <td align="right">value</td><td> : </td>
        <td>
          <xsl:value-of select="$Value"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="$Currency"/>
          <xsl:if test="$IsValueEst = 'true'">
            <xsl:text> </xsl:text>
            <xsl:text>[E]</xsl:text>
          </xsl:if>
        </td>
      </tr>
    </xsl:if>

    <xsl:if test="$Name">
      <tr valign="top">
        <td align="right">name</td><td> : </td>
        <td><xsl:value-of select="$Name"/></td>
      </tr>
    </xsl:if>

    <xsl:if test="$Country|$City|$Zip|$Address">
      <tr valign="top">
        <td align="right">address</td><td> : </td>
        <td>
          <xsl:call-template name="row_address">
<xsl:with-param name="Ttype" select="''"></xsl:with-param>
<xsl:with-param name="Tname" select="''"></xsl:with-param>
<xsl:with-param name="Tcoun" select="'addr.country'"></xsl:with-param>
<xsl:with-param name="Tcity" select="'addr.city'"></xsl:with-param>
<xsl:with-param name="Tzip"  select="'addr.zip'"></xsl:with-param>
<xsl:with-param name="Taddr" select="'addr.address'"></xsl:with-param>
          </xsl:call-template>          
        </td>
      </tr>
    </xsl:if>

    </table>
  </td>
</tr>

</xsl:template>


<!-- row start - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="AssetsOther.Row.start">
  <xsl:choose>
    <xsl:when test="position() = 1">
<td/><td>:</td>
    </xsl:when>
    <xsl:otherwise>
<td/><td> </td>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


</xsl:stylesheet>
