<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Defaults']">
  <xsl:variable name="title" select="'Defaults Registered'"/>
  <tr><td colspan="3"><strong><xsl:value-of select="$title"/></strong></td></tr>

  <xsl:apply-templates select="group"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Defaults']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Defaults.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top">
    <xsl:call-template name="Defaults.Row.start"/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Defaults.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="row_timestamps" />
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Defaults.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:Defaults.Row']/item[1]">

  <xsl:variable name="IsPresence"      select="../item[@type='is.presence']"/>
  <xsl:variable name="Cause"           select="../item[@type='cause']"/>
  <xsl:variable name="Status"          select="../item[@type='status']"/>
  <xsl:variable name="Amount"          select="../item[@type='amount']"/>
  <xsl:variable name="Currency"        select="../item[@type='currency']"/>
  <xsl:variable name="IsAmountEst"     select="../item[@type='is.amount.est']"/>
  <xsl:variable name="Claimant"        select="../item[@type='claimant']"/>
  <xsl:variable name="Type"            select="../item[@type='type']"/>
  <xsl:variable name="Gender"          select="../item[@type='gender']"/>
  <xsl:variable name="Igkno"           select="../item[@type='igkno']"/>
  <xsl:variable name="Origin"          select="../item[@type='origin']"/>
  <xsl:variable name="Regno"           select="../item[@type='regno']"/>
  <xsl:variable name="Addr.country"    select="../item[@type='addr.country']"/>
  <xsl:variable name="Addr.city"       select="../item[@type='addr.city']"/>
  <xsl:variable name="Addr.zip"        select="../item[@type='addr.zip']"/>
  <xsl:variable name="Addr.address"    select="../item[@type='addr.address']"/>

<tr valign="top">
  <xsl:call-template name="Defaults.Row.start"/>
  <td>
    <xsl:choose>
      <xsl:when test="$IsPresence = 'true'">
        <xsl:text>yes</xsl:text><br/>
      </xsl:when>
      <xsl:when test="$IsPresence = 'false'">
        <xsl:text>none</xsl:text><br/>
      </xsl:when>
      <xsl:otherwise/>
    </xsl:choose>

    <table cellSpacing="0" cellPadding="0" width="95%">
      <colgroup>
<col width="100"/>
<col width="10"/>
<col width="220"/>
<col width="170" align="right"/>
      </colgroup>
      <tr valign="top">
        <td colspan="3">
          <xsl:value-of select="$Cause"/>
        </td>
        <td align="right">
          <xsl:value-of select="$Amount"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="$Currency"/>
          <xsl:if test="$IsAmountEst = 'true'">
            <xsl:text> </xsl:text>
            <xsl:text>[E]</xsl:text>
          </xsl:if>
        </td>
      </tr>
    <xsl:if test="$Status">
      <tr valign="top">
        <td align="right">status</td><td>:</td>
        <td><xsl:value-of select="$Status"/></td>
      </tr>
    </xsl:if>

    <xsl:if test="$Claimant">
      <tr valign="top">
        <td align="right">claimant</td><td>:</td>
        <td>
          <xsl:if test="$Type = 'person'">
            <xsl:choose>
              <xsl:when test="$Gender = 'male'">Mr </xsl:when>
              <xsl:when test="$Gender = 'female'">Mrs </xsl:when>
              <xsl:otherwise/>
            </xsl:choose>
          </xsl:if>
          <xsl:value-of select="$Claimant"/>

          <xsl:if test="$Origin">
            <xsl:text disable-output-escaping="yes"> &lt;i&gt;(</xsl:text>
            <xsl:call-template name="row_address">
<xsl:with-param name="Ttype" select="''"></xsl:with-param>
<xsl:with-param name="Tname" select="''"></xsl:with-param>
<xsl:with-param name="Tcoun" select="'origin'"></xsl:with-param>
<xsl:with-param name="Tcity" select="''"></xsl:with-param>
<xsl:with-param name="Tzip"  select="''"></xsl:with-param>
<xsl:with-param name="Taddr" select="''"></xsl:with-param>
            </xsl:call-template>          
            <xsl:text disable-output-escaping="yes">)&lt;/i&gt;</xsl:text>
          </xsl:if>

          <xsl:if test="$Regno">
<br/>
<xsl:text>reg. number: </xsl:text>
<xsl:value-of select="$Regno"/>
          </xsl:if>

          <xsl:if test="($Addr.city|$Addr.zip|$Addr.address) or ($Addr.country != $Origin)">
<br/>
<xsl:text>address: </xsl:text>
            <xsl:call-template name="row_address">
<xsl:with-param name="Ttype" select="''"></xsl:with-param>
<xsl:with-param name="Tname" select="''"></xsl:with-param>
<xsl:with-param name="Tcoun" select="'addr.country'"></xsl:with-param>
<xsl:with-param name="Tcity" select="'addr.city'"></xsl:with-param>
<xsl:with-param name="Tzip"  select="'addr.zip'"></xsl:with-param>
<xsl:with-param name="Taddr" select="'addr.address'"></xsl:with-param>
            </xsl:call-template>          
          </xsl:if>

        </td>
      </tr>
    </xsl:if>

    </table>
  </td>
</tr>

</xsl:template>


<!-- row start - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="Defaults.Row.start">
  <xsl:choose>
    <xsl:when test="position() = 1">
      <xsl:variable name="Date" select="../item[@type='date']"/>
<td>
  <xsl:value-of select="$Date"/>
</td><td>:</td>
    </xsl:when>
    <xsl:otherwise>
<td/><td> </td>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


</xsl:stylesheet>
