<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialData']">
  <xsl:variable name="title" select="'FinancialData'"/>
  <tr><td colspan="3"><strong><xsl:value-of select="$title"/></strong></td></tr>

  <xsl:apply-templates select="group"/>
<!-- output order:
  - topic comments (top), as they follow in the document
  - compound table for 1-3 rows:
    - *) 1st row's top comments
    - **) 2nd row's top comments
    - ***) 3rd row's top comments
    - 1-3 rows table
    - *) 1st row's bottom comments
    - **) 2nd row's bottom comments
    - ***) 3rd row's bottom comments
  - topic comments (bottom), as they follow in the document

notes:
  - row comment is in <pre>
-->
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialData']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- 1+ row processing (skip)  - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialData.Row'][position()>1]" />

<!-- 1st row processing  - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialData.Row'][1]">

  <xsl:variable name="Rows" select="../group[@type='cr:FinancialData.Row']"/>
<!--
  <xsl:for-each select="$Rows">
cr:FinStmts.Row(<xsl:value-of select="concat(position(),', ',@type,', ',node())"/>)<br/>
  </xsl:for-each>
cr:FinStmts.Rows, count = <xsl:value-of select="count($Rows)"/><br/>
-->
<xsl:if test="count($Rows) > 0">

   <xsl:variable name="Size" select="count($Rows)"/>

   <xsl:variable name="Row1.comms.top"    select="$Rows[1]/group[@type='cr:RowComments.Row' and item[@type='is.top']='true']"/>
   <xsl:variable name="Row1.comms.bottom" select="$Rows[1]/group[@type='cr:RowComments.Row' and not(item[@type='is.top']='true')]"/>

   <xsl:variable name="Row2.comms.top"    select="$Rows[2]/group[@type='cr:RowComments.Row' and item[@type='is.top']='true']"/>
   <xsl:variable name="Row2.comms.bottom" select="$Rows[2]/group[@type='cr:RowComments.Row' and not(item[@type='is.top']='true')]"/>

   <xsl:variable name="Row3.comms.top"    select="$Rows[3]/group[@type='cr:RowComments.Row' and item[@type='is.top']='true']"/>
   <xsl:variable name="Row3.comms.bottom" select="$Rows[3]/group[@type='cr:RowComments.Row' and not(item[@type='is.top']='true')]"/>

<tr valign="top">
  <td colspan="3">
    <table cellSpacing="0" cellPadding="0" width="95%">
      <colgroup>
<col width="25"/>
<col width="575"/>
      </colgroup>

      <xsl:call-template name="FinancialData.RowComments">
        <xsl:with-param name="Nodes" select="$Row1.comms.top"/>
        <xsl:with-param name="Index" select="1"/>
      </xsl:call-template>

      <xsl:call-template name="FinancialData.RowComments">
        <xsl:with-param name="Nodes" select="$Row2.comms.top"/>
        <xsl:with-param name="Index" select="2"/>
      </xsl:call-template>

      <xsl:call-template name="FinancialData.RowComments">
        <xsl:with-param name="Nodes" select="$Row3.comms.top"/>
        <xsl:with-param name="Index" select="3"/>
      </xsl:call-template>

    </table>
  </td>
</tr>

<tr valign="top">
  <td colspan="3">
    <table border="0" cellSpacing="0" cellPadding="0" width="100%">
      <colgroup>
<col width="130"/>
<col width="130"/>
<col width="130"/>
<col width="130"/>
<col width="130"/>
      </colgroup>

      <xsl:call-template name="FinancialData.RowDetails.Headers">
        <xsl:with-param name="Nodes" select="$Rows"/>
      </xsl:call-template>

      <xsl:call-template name="FinancialData.RowDetails.Indicators">
        <xsl:with-param name="Size" select="$Size"/>
        <xsl:with-param name="Size1" select="count($Row1.comms.top)+count($Row1.comms.bottom)"/>
        <xsl:with-param name="Size2" select="count($Row2.comms.top)+count($Row2.comms.bottom)"/>
        <xsl:with-param name="Size3" select="count($Row3.comms.top)+count($Row3.comms.bottom)"/>
      </xsl:call-template>

      <xsl:call-template name="tr_empty"/>

      <xsl:call-template name="FinancialData.RowDetails.Statements">
        <xsl:with-param name="Nodes" select="$Rows"/>
      </xsl:call-template>

      <xsl:call-template name="tr_empty"/>

      <xsl:call-template name="FinancialData.RowDetails.Ratios">
        <xsl:with-param name="Nodes" select="$Rows"/>
      </xsl:call-template>

    </table>
  </td>
</tr>
<xsl:call-template name="tr_empty"/>

<tr valign="top">
  <td colspan="3">
    <table cellSpacing="0" cellPadding="0" width="95%">
      <colgroup>
<col width="25"/>
<col width="575"/>
      </colgroup>

      <xsl:call-template name="FinancialData.RowComments">
        <xsl:with-param name="Nodes" select="$Row1.comms.bottom"/>
        <xsl:with-param name="Index" select="1"/>
      </xsl:call-template>

      <xsl:call-template name="FinancialData.RowComments">
        <xsl:with-param name="Nodes" select="$Row2.comms.bottom"/>
        <xsl:with-param name="Index" select="2"/>
      </xsl:call-template>

      <xsl:call-template name="FinancialData.RowComments">
        <xsl:with-param name="Nodes" select="$Row3.comms.bottom"/>
        <xsl:with-param name="Index" select="3"/>
      </xsl:call-template>

    </table>
  </td>
</tr>

</xsl:if>
</xsl:template>


<!-- row-comments processing - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowComments">
<xsl:param name="Nodes"/>
<xsl:param name="Index"/>

  <xsl:for-each select="$Nodes">
<!--
cr:FinStmts.RowComms(<xsl:value-of select="concat(position(),', ',@type,', ',node())"/>)<br/>
-->
    <xsl:call-template name="FinancialData.RowComments.Row">
      <xsl:with-param name="Index" select="$Index"/>
    </xsl:call-template>
  </xsl:for-each>

</xsl:template>

<!-- row-comment processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowComments.Row">
<xsl:param name="Index"/>

  <tr valign="top">
    <td>

    <xsl:if test="position() = 1">
      <xsl:choose>
        <xsl:when test="$Index = 1">
          <xsl:call-template name="PutData.pre.small">
            <xsl:with-param name="Value" select="'*)'"/>
          </xsl:call-template>
        </xsl:when>

        <xsl:when test="$Index = 2">
          <xsl:call-template name="PutData.pre.small">
            <xsl:with-param name="Value" select="'**)'"/>
          </xsl:call-template>
        </xsl:when>

        <xsl:when test="$Index = 3">
          <xsl:call-template name="PutData.pre.small">
            <xsl:with-param name="Value" select="'***)'"/>
          </xsl:call-template>
        </xsl:when>

        <xsl:otherwise/>
      </xsl:choose>
    </xsl:if>

    </td>
    <xsl:call-template name="td_comment_pre"/>
  </tr>
  <xsl:call-template name="tr_empty"/>

</xsl:template>


<!-- row-details processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.Headers">
<xsl:param name="Nodes"/>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Period, months'"/>
  <xsl:with-param name="Type"  select="'months'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Ended'"/>
  <xsl:with-param name="Type"  select="'revision'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.currency">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Currency'"/>
  <xsl:with-param name="Type"  select="'currency'"/>
  <xsl:with-param name="Type2" select="'degree'"/>
</xsl:call-template>

</xsl:template>


<!-- row-details processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.Indicators">
<xsl:param name="Size"/>
<xsl:param name="Size1"/>
<xsl:param name="Size2"/>
<xsl:param name="Size3"/>

<tr valign="top">

  <xsl:choose>
    <xsl:when test="$Size=3">

<td colspan="2">
  <xsl:if test="$Size1 > 0 or $Size2 > 0 or $Size3 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'Comments'"/>
    </xsl:call-template>
  </xsl:if>
</td>
<td align="right">
  <xsl:if test="$Size1 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'*)'"/>
    </xsl:call-template>
  </xsl:if>
</td>
<td align="right">
  <xsl:if test="$Size2 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'**)'"/>
    </xsl:call-template>
  </xsl:if>
</td>
<td align="right">
  <xsl:if test="$Size3 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'***)'"/>
    </xsl:call-template>
  </xsl:if>
</td>

    </xsl:when>

    <xsl:when test="$Size=2">

<td/>
<td>
  <xsl:if test="$Size1 > 0 or $Size2 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'Comments'"/>
    </xsl:call-template>
  </xsl:if>
</td>
<td align="right">
  <xsl:if test="$Size1 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'*)'"/>
    </xsl:call-template>
  </xsl:if>
</td>
<td align="right">
  <xsl:if test="$Size2 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'**)'"/>
    </xsl:call-template>
  </xsl:if>
</td>

    </xsl:when>

    <xsl:when test="$Size=1">

<td colspan="2"/>
<td>
  <xsl:if test="$Size1 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'Comments'"/>
    </xsl:call-template>
  </xsl:if>
</td>
<td align="right">
  <xsl:if test="$Size1 > 0">
    <xsl:call-template name="PutData.pre.small">
      <xsl:with-param name="Value" select="'*)'"/>
    </xsl:call-template>
  </xsl:if>
</td>

    </xsl:when>

    <xsl:otherwise/>
  </xsl:choose>

</tr>

</xsl:template>


<!-- row-details processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.Statements">
<xsl:param name="Nodes"/>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Non-current assets'"/>
  <xsl:with-param name="Type"  select="'non-current assets'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'  incl: - Fixed assets'"/>
  <xsl:with-param name="Type"  select="'fixed assets'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'        - Financial assets'"/>
  <xsl:with-param name="Type"  select="'financial assets'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Current assets'"/>
  <xsl:with-param name="Type"  select="'current assets'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'  incl: - Stock'"/>
  <xsl:with-param name="Type"  select="'stock'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'        - Debtors'"/>
  <xsl:with-param name="Type"  select="'debtors'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'        - Cash'"/>
  <xsl:with-param name="Type"  select="'cash'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'ASSETS TOTAL'"/>
  <xsl:with-param name="Type"  select="'assets total'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Equity'"/>
  <xsl:with-param name="Type"  select="'equity'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'  incl: - Share capital'"/>
  <xsl:with-param name="Type"  select="'share capital'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Liabilities Total'"/>
  <xsl:with-param name="Type"  select="'liabilities total'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'  incl: - Long-term liabilities'"/>
  <xsl:with-param name="Type"  select="'long-term liabs'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'        - Short-term liabilities'"/>
  <xsl:with-param name="Type"  select="'short-term liabs'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'EQUITY AND LIABILITIES TOTAL'"/>
  <xsl:with-param name="Type"  select="'equity+liabs total'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Net sales'"/>
  <xsl:with-param name="Type"  select="'net sales'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Cost of goods sold'"/>
  <xsl:with-param name="Type"  select="'cost of goods sold'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Operating profit'"/>
  <xsl:with-param name="Type"  select="'operating profit'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Profit before taxation'"/>
  <xsl:with-param name="Type"  select="'profit before tax'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Net profit'"/>
  <xsl:with-param name="Type"  select="'net profit'"/>
</xsl:call-template>

</xsl:template>


<!-- row-details processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.Ratios">
<xsl:param name="Nodes"/>

<xsl:call-template name="FinancialData.RowDetails.tr">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'- - - R a t i o s - - - - - - - - - -'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Return on sales, %'"/>
  <xsl:with-param name="Title2" select="'  Profit before taxation / Net sales'"/>
  <xsl:with-param name="Type"  select="'r: Return on sales, %'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Operating margin of profit, %'"/>
  <xsl:with-param name="Title2" select="'  Operating profit / Net sales'"/>
  <xsl:with-param name="Type"  select="'r: Operating margin, %'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Return on investment, %'"/>
  <xsl:with-param name="Title2" select="'  Profit before taxation / Equity'"/>
  <xsl:with-param name="Type"  select="'r: Return on invest, %'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Current assets turnover'"/>
  <xsl:with-param name="Title2" select="'  Net sales / Current assets'"/>
  <xsl:with-param name="Type"  select="'r: Curr.assets turnover'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Working capital'"/>
  <xsl:with-param name="Title2" select="'  Current assets - Short-term liabilities'"/>
  <xsl:with-param name="Type"  select="'Working capital'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Leverage'"/>
  <xsl:with-param name="Title2" select="'  Equity / Total assets'"/>
  <xsl:with-param name="Type"  select="'r: Leverage'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Current ratio'"/>
  <xsl:with-param name="Title2" select="'  Current assets / Short-term liabilities'"/>
  <xsl:with-param name="Type"  select="'r: Current ratio'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Quick ratio'"/>
  <xsl:with-param name="Title2" select="'  (Current assets - Stock) / Short-term liabilities'"/>
  <xsl:with-param name="Type"  select="'r: Quick ratio'"/>
</xsl:call-template>

<xsl:call-template name="FinancialData.RowDetails.tr.ratio">
  <xsl:with-param name="Nodes" select="$Nodes"/>
  <xsl:with-param name="Title" select="'Debt-to-equity ratio'"/>
  <xsl:with-param name="Title2" select="'  Total liabilities / Equity'"/>
  <xsl:with-param name="Type"  select="'r: Debt-to-equity'"/>
</xsl:call-template>

</xsl:template>

<!-- row-details processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr">
<xsl:param name="Nodes"/>
<xsl:param name="Title"/>
<xsl:param name="Type"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>
<xsl:param name="Value3"/>

  <xsl:variable name="Size" select="count($Nodes)"/>

  <xsl:choose>
    <xsl:when test="$Size=3 and $Type">
<xsl:call-template name="FinancialData.RowDetails.tr.3">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
  <xsl:with-param name="Value2" select="$Nodes[2]/item[@type=$Type]"/>
  <xsl:with-param name="Value3" select="$Nodes[3]/item[@type=$Type]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=3 and not($Type)">
<xsl:call-template name="FinancialData.RowDetails.tr.3">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Value1"/>
  <xsl:with-param name="Value2" select="$Value2"/>
  <xsl:with-param name="Value3" select="$Value3"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=2 and $Type">
<xsl:call-template name="FinancialData.RowDetails.tr.2">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
  <xsl:with-param name="Value2" select="$Nodes[2]/item[@type=$Type]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=2 and not($Type)">
<xsl:call-template name="FinancialData.RowDetails.tr.2">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Value1"/>
  <xsl:with-param name="Value2" select="$Value2"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=1 and $Type">
<xsl:call-template name="FinancialData.RowDetails.tr.1">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=1 and not($Type)">
<xsl:call-template name="FinancialData.RowDetails.tr.1">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Value1"/>
</xsl:call-template>
    </xsl:when>

    <xsl:otherwise/>
  </xsl:choose>

</xsl:template>


<!-- row-details processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.ratio">
<xsl:param name="Nodes"/>
<xsl:param name="Title"/>
<xsl:param name="Title2"/>
<xsl:param name="Type"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>
<xsl:param name="Value3"/>

  <xsl:variable name="Size" select="count($Nodes)"/>

  <xsl:choose>
    <xsl:when test="$Size=3 and $Type">
<xsl:call-template name="FinancialData.RowDetails.tr.ratio.3">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Title2" select="$Title2"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
  <xsl:with-param name="Value2" select="$Nodes[2]/item[@type=$Type]"/>
  <xsl:with-param name="Value3" select="$Nodes[3]/item[@type=$Type]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=3 and not($Type)">
<xsl:call-template name="FinancialData.RowDetails.tr.ratio.3">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Title2" select="$Title2"/>
  <xsl:with-param name="Value1" select="$Value1"/>
  <xsl:with-param name="Value2" select="$Value2"/>
  <xsl:with-param name="Value3" select="$Value3"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=2 and $Type">
<xsl:call-template name="FinancialData.RowDetails.tr.ratio.2">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Title2" select="$Title2"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
  <xsl:with-param name="Value2" select="$Nodes[2]/item[@type=$Type]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=2 and not($Type)">
<xsl:call-template name="FinancialData.RowDetails.tr.ratio.2">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Title2" select="$Title2"/>
  <xsl:with-param name="Value1" select="$Value1"/>
  <xsl:with-param name="Value2" select="$Value2"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=1 and $Type">
<xsl:call-template name="FinancialData.RowDetails.tr.ratio.1">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Title2" select="$Title2"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=1 and not($Type)">
<xsl:call-template name="FinancialData.RowDetails.tr.ratio.1">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Title2" select="$Title2"/>
  <xsl:with-param name="Value1" select="$Value1"/>
</xsl:call-template>
    </xsl:when>

    <xsl:otherwise/>
  </xsl:choose>

</xsl:template>



<!-- row-details processing  - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.currency">
<xsl:param name="Nodes"/>
<xsl:param name="Title"/>
<xsl:param name="Type"/>
<xsl:param name="Type2"/>

  <xsl:variable name="Size" select="count($Nodes)"/>

  <xsl:choose>
    <xsl:when test="$Size=3">
<xsl:call-template name="FinancialData.RowDetails.tr.currency.3">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
  <xsl:with-param name="Value2" select="$Nodes[2]/item[@type=$Type]"/>
  <xsl:with-param name="Value3" select="$Nodes[3]/item[@type=$Type]"/>
  <xsl:with-param name="Degree1" select="$Nodes[1]/item[@type=$Type2]"/>
  <xsl:with-param name="Degree2" select="$Nodes[2]/item[@type=$Type2]"/>
  <xsl:with-param name="Degree3" select="$Nodes[3]/item[@type=$Type2]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=2">
<xsl:call-template name="FinancialData.RowDetails.tr.currency.2">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
  <xsl:with-param name="Value2" select="$Nodes[2]/item[@type=$Type]"/>
  <xsl:with-param name="Degree1" select="$Nodes[1]/item[@type=$Type2]"/>
  <xsl:with-param name="Degree2" select="$Nodes[2]/item[@type=$Type2]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:when test="$Size=1">
<xsl:call-template name="FinancialData.RowDetails.tr.currency.1">
  <xsl:with-param name="Title"  select="$Title"/>
  <xsl:with-param name="Value1" select="$Nodes[1]/item[@type=$Type]"/>
  <xsl:with-param name="Degree1" select="$Nodes[1]/item[@type=$Type2]"/>
</xsl:call-template>
    </xsl:when>

    <xsl:otherwise/>
  </xsl:choose>

</xsl:template>



<!-- row-details, 3 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.3">
<xsl:param name="Title"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>
<xsl:param name="Value3"/>

<tr valign="top">

<td colspan="2">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value1"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value2"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value3"/>
  </xsl:call-template>
</td>

</tr>

</xsl:template>

<!-- row-details, 2 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.2">
<xsl:param name="Title"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>

<tr valign="top">

<td/>
<td>
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value1"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value2"/>
  </xsl:call-template>
</td>

</tr>

</xsl:template>

<!-- row-details, 1 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.1">
<xsl:param name="Title"/>
<xsl:param name="Value1"/>

<tr valign="top">

<td/>
<td/>
<td>
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value1"/>
  </xsl:call-template>
</td>

</tr>

</xsl:template>


<!-- row-details, 3 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.ratio.3">
<xsl:param name="Title"/>
<xsl:param name="Title2"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>
<xsl:param name="Value3"/>

<tr class="light-grey" valign="top">

<td colspan="2">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value1"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value2"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value3"/>
  </xsl:call-template>
</td>

</tr>

<tr valign="top">
<td colspan="2">
  <xsl:call-template name="PutData.pre.small">
    <xsl:with-param name="Value" select="$Title2"/>
  </xsl:call-template>
</td>
</tr>

</xsl:template>

<!-- row-details, 2 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.ratio.2">
<xsl:param name="Title"/>
<xsl:param name="Title2"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>

<tr class="light-grey" valign="top">

<td/>
<td>
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value1"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value2"/>
  </xsl:call-template>
</td>

<tr valign="top">
<td/>
<td>
  <xsl:call-template name="PutData.pre.small">
    <xsl:with-param name="Value" select="$Title2"/>
  </xsl:call-template>
</td>
</tr>

</tr>

</xsl:template>

<!-- row-details, 1 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.ratio.1">
<xsl:param name="Title"/>
<xsl:param name="Title2"/>
<xsl:param name="Value1"/>

<tr class="light-grey" valign="top">

<td/>
<td/>
<td>
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Value1"/>
  </xsl:call-template>
</td>

</tr>

<tr valign="top">
<td/><td/>
<td>
  <xsl:call-template name="PutData.pre.small">
    <xsl:with-param name="Value" select="$Title2"/>
  </xsl:call-template>
</td>
</tr>

</xsl:template>


<!-- row-details, 3 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.currency.3">
<xsl:param name="Title"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>
<xsl:param name="Value3"/>
<xsl:param name="Degree1"/>
<xsl:param name="Degree2"/>
<xsl:param name="Degree3"/>

<tr valign="top">

<td colspan="2">
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre.currency">
    <xsl:with-param name="Value" select="$Value1"/>
    <xsl:with-param name="Degree" select="$Degree1"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre.currency">
    <xsl:with-param name="Value" select="$Value2"/>
    <xsl:with-param name="Degree" select="$Degree2"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre.currency">
    <xsl:with-param name="Value" select="$Value3"/>
    <xsl:with-param name="Degree" select="$Degree3"/>
  </xsl:call-template>
</td>

</tr>

</xsl:template>

<!-- row-details, 2 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.currency.2">
<xsl:param name="Title"/>
<xsl:param name="Value1"/>
<xsl:param name="Value2"/>
<xsl:param name="Degree1"/>
<xsl:param name="Degree2"/>

<tr valign="top">

<td/>
<td>
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre.currency">
    <xsl:with-param name="Value" select="$Value1"/>
    <xsl:with-param name="Degree" select="$Degree1"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre.currency">
    <xsl:with-param name="Value" select="$Value2"/>
    <xsl:with-param name="Degree" select="$Degree2"/>
  </xsl:call-template>
</td>

</tr>

</xsl:template>

<!-- row-details, 1 cols - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialData.RowDetails.tr.currency.1">
<xsl:param name="Title"/>
<xsl:param name="Value1"/>
<xsl:param name="Degree1"/>

<tr valign="top">

<td/>
<td/>
<td>
  <xsl:call-template name="PutData.pre">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</td>
<td align="right">
  <xsl:call-template name="PutData.pre.currency">
    <xsl:with-param name="Value" select="$Value1"/>
    <xsl:with-param name="Degree" select="$Degree1"/>
  </xsl:call-template>
</td>

</tr>

</xsl:template>



</xsl:stylesheet>
