<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
>
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
<!--
xmlns:fn="http://www.w3.org/2005/04/xpath-functions"
  <xsl:strip-space elements="*" />
-->

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialStatements']">
  <xsl:variable name="title" select="'Financial Statements'"/>
  <tr><td colspan="3"><strong><xsl:value-of select="$title"/></strong></td></tr>

  <xsl:apply-templates select="group"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialStatements']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <tr><td colspan="3"><br/></td></tr>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialStatements.Row']/group[@type='cr:RowComments.Row']">
<tr valign="top">
  <xsl:call-template name="FinancialStatements.Row.start"/>
  <xsl:call-template name="td_comment"/>
</tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialStatements.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="row_timestamps" />
  <tr><td colspan="3"><br/></td></tr>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:FinancialStatements.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:FinancialStatements.Row']/group[@type='src.document']/*" />

<xsl:template match="group[@type='cr:FinancialStatements.Row']/item[1]">

<tr valign="top">
  <xsl:call-template name="FinancialStatements.Row.start"/>

  <xsl:variable name="Months"   select="../item[@type='months']"/>
  <xsl:variable name="Currency" select="../item[@type='currency']"/>
  <xsl:variable name="Degree"   select="../item[@type='degree']"/>

  <td>
Fiscal period: <i><xsl:value-of select="$Months"/></i> month(s)
, currency: <i><xsl:value-of select="$Currency"/></i>
    <xsl:if test="$Degree != ''">
, unit: <i>
  <xsl:choose>
    <xsl:when test="$Degree='3'"> th </xsl:when>
    <xsl:when test="$Degree='6'"> mio </xsl:when>
    <xsl:otherwise/>
  </xsl:choose>
</i>
    </xsl:if>

    <xsl:variable name="SrcDocument" select="../group[@type='src.document']"/>

    <xsl:if test="$SrcDocument">
      <xsl:call-template name="FinancialStatements.Row.SrcDocument">
        <xsl:with-param name="Root" select="$SrcDocument"/>
      </xsl:call-template>
    </xsl:if>
  </td>
</tr>

</xsl:template>


<!-- row start - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialStatements.Row.start">
  <xsl:choose>
    <xsl:when test="position() = 1">
      <xsl:variable name="Date" select="../item[@type='revision']"/>
<td><xsl:value-of select="$Date"/></td><td>:</td>
    </xsl:when>
    <xsl:otherwise>
<td/><td/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- row source document - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="FinancialStatements.Row.SrcDocument">
<xsl:param name="Root"/>
<p/>
  <table cellSpacing="0" cellPadding="0" width="100%">
    <colgroup>
<col width="370"/>
<col width="200"/>
<col width="30"/>
    </colgroup>

  <xsl:for-each select="$Root/group[@type='line']">
    <xsl:variable name="Title" select="item[@type='tit']"/>
    <xsl:variable name="Value" select="item[@type='val']"/>
    <xsl:variable name="Estim" select="item[@type='est']"/>

    <tr valign="top">
      <td>
<xsl:if test="$Title">
  <xsl:call-template name="PutData.pre.small">
    <xsl:with-param name="Value" select="$Title"/>
  </xsl:call-template>
</xsl:if>
      </td>
      <td align="right">
<xsl:if test="$Value">
  <xsl:call-template name="PutData.pre.small">
    <xsl:with-param name="Value" select="$Value"/>
  </xsl:call-template>
</xsl:if>
      </td>
      <td align="right">
<xsl:if test="$Estim">
  <xsl:call-template name="PutData.pre.small">
    <xsl:with-param name="Value" select="'[E]'"/>
  </xsl:call-template>
</xsl:if>
      </td>
    </tr>

  </xsl:for-each>

  </table>

</xsl:template>


</xsl:stylesheet>
