<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Debts']">
  <xsl:variable name="title" select="'Debts Registered'"/>
  <tr><td colspan="3"><strong><xsl:value-of select="$title"/></strong></td></tr>

  <xsl:apply-templates select="group"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Debts']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Debts.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top">
    <xsl:call-template name="Debts.Row.start"/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Debts.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="row_timestamps" />
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Debts.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:Debts.Row']/item[1]">
<!--
cr:Debts.Row/item(<xsl:value-of select="concat(position(),', ',@type,', ',node())"/>), in<br/>
-->
  <xsl:variable name="IsPresence"      select="../item[@type='is.presence']"/>
  <xsl:variable name="Type"            select="../item[@type='type']"/>
  <xsl:variable name="IsConfirmed"     select="../item[@type='is.confirmed']"/>
  <xsl:variable name="Amount"          select="../item[@type='amount']"/>
  <xsl:variable name="Currency"        select="../item[@type='currency']"/>
  <xsl:variable name="IsAmountEst"     select="../item[@type='is.amount.est']"/>
  <xsl:variable name="Penalty"         select="../item[@type='penalty']"/>
  <xsl:variable name="PCurrency"       select="../item[@type='p.currency']"/>
  <xsl:variable name="IsPenaltyEst"    select="../item[@type='is.penalty.est']"/>
  <xsl:variable name="PaymentStatus"   select="../item[@type='payment.status']"/>

<xsl:if test="$Type != 'Local databases' or $IsPresence = 'true' or
not(../../group[@type='cr:Debts.Row' and (./item[@type='type'] != $Type)]) ">

<tr valign="top">
  <xsl:call-template name="Debts.Row.start"/>
  <td>
    <xsl:choose>
      <xsl:when test="$IsPresence = 'true' and $Type = 'Local databases'">
        <xsl:text>Local databases have record(s) filed on the subject.</xsl:text><br/>
      </xsl:when>
      <xsl:when test="$IsPresence = 'false' and $Type = 'Local databases'">
        <xsl:text>There is no any record filed in the local databases.</xsl:text><br/>
      </xsl:when>
      <xsl:when test="$IsPresence = 'true'">
        <xsl:text>yes</xsl:text><br/>
      </xsl:when>
      <xsl:when test="$IsPresence = 'false'">
        <xsl:text>none</xsl:text><br/>
      </xsl:when>
      <xsl:otherwise/>
    </xsl:choose>

<xsl:if test="not($IsPresence) and $Type|$Amount|$Penalty|$PaymentStatus">

    <table cellSpacing="0" cellPadding="0" width="95%">
      <colgroup>
<col width="140"/>
<col width="10"/>
<col width="180"/>
<col width="170" align="right"/>
      </colgroup>
      <tr valign="top">
        <td colspan="3">
          <xsl:value-of select="$Type"/>
    <xsl:if test="$IsConfirmed">
          <xsl:text> </xsl:text>
<i>(
          <xsl:choose>
            <xsl:when test="$IsConfirmed = 'true'">confirmed</xsl:when>
            <xsl:when test="$IsConfirmed = 'false'">unconfirmed</xsl:when>
            <xsl:otherwise/>
          </xsl:choose>
)</i>
    </xsl:if>
        </td>
    <xsl:if test="$Amount">
        <td align="right">
          <xsl:value-of select="$Amount"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="$Currency"/>
          <xsl:if test="$IsAmountEst = 'true'">
            <xsl:text> </xsl:text>
            <xsl:text>[E]</xsl:text>
          </xsl:if>
        </td>
    </xsl:if>
      </tr>

    <xsl:if test="$Penalty">
      <tr valign="top">
        <td align="right">penalty</td><td>:</td>
        <td>
          <xsl:value-of select="$Penalty"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="$PCurrency"/>
          <xsl:if test="$IsPenaltyEst = 'true'">
            <xsl:text> </xsl:text>
            <xsl:text>[E]</xsl:text>
          </xsl:if>
        </td>
      </tr>
    </xsl:if>

    <xsl:if test="$PaymentStatus">
      <tr valign="top">
        <td align="right">payment status</td><td>:</td>
        <td><xsl:value-of select="$PaymentStatus"/></td>
      </tr>
    </xsl:if>

    </table>

</xsl:if>

  </td>
</tr>

</xsl:if>
<!--
cr:Debts.Row/item(<xsl:value-of select="concat(position(),', ',@type,', ',node())"/>), out<br/>
-->
</xsl:template>


<!-- row start - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="Debts.Row.start">
<!--
Debts.Row.start(<xsl:value-of select="node()"/>), in<br/>
-->
  <xsl:choose>
    <xsl:when test="position() = 1">
      <xsl:variable name="Date" select="../item[@type='date']"/>
<td>
  <xsl:value-of select="$Date"/>
</td><td>:</td>
    </xsl:when>
    <xsl:otherwise>
<td/><td> </td>
    </xsl:otherwise>
  </xsl:choose>
<!--
Debts.Row.start(<xsl:value-of select="node()"/>), out<br/>
-->
</xsl:template>


</xsl:stylesheet>
