<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ManagersExecutives']">
  <xsl:variable name="title" select="'Executives'"/>
  <tr><td colspan="3"><i><strong><xsl:value-of select="$title"/></strong></i></td></tr>

  <xsl:apply-templates select="group"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ManagersExecutives']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ManagersExecutives.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top">
    <xsl:call-template name="ManagersExecutives.Row.start"/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ManagersExecutives.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="row_timestamps" />
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ManagersExecutives.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:ManagersExecutives.Row']/item[1]">

  <xsl:variable name="Name"            select="../item[@type='name']"/>
  <xsl:variable name="Gender"          select="../item[@type='gender']"/>
  <xsl:variable name="Igkno"           select="../item[@type='igkno']"/>
  <xsl:variable name="Origin"          select="../item[@type='origin']"/>
  <xsl:variable name="PersCode"        select="../item[@type='pers.code']"/>
<!--
  <xsl:variable name="AsBoard"         select="../item[@type='as.board']"/>
  <xsl:variable name="AsExecutive"     select="../item[@type='as.executive']"/>
-->
  <xsl:variable name="IsSignature"     select="../item[@type='is.signature']"/>
  <xsl:variable name="Addr.country"    select="../item[@type='addr.country']"/>
  <xsl:variable name="Addr.city"       select="../item[@type='addr.city']"/>
  <xsl:variable name="Addr.zip"        select="../item[@type='addr.zip']"/>
  <xsl:variable name="Addr.address"    select="../item[@type='addr.address']"/>

<tr valign="top">
  <xsl:call-template name="ManagersExecutives.Row.start"/>
  <td>
    <table cellSpacing="0" cellPadding="0" width="95%">
      <colgroup>
<col width="145"/>
<col width="10"/>
<col width="345"/>
      </colgroup>
      <tr valign="top">
        <td colspan="3">
          <xsl:choose>
            <xsl:when test="$Gender = 'male'">Mr </xsl:when>
            <xsl:when test="$Gender = 'female'">Mrs </xsl:when>
            <xsl:otherwise/>
          </xsl:choose>
          <xsl:value-of select="$Name"/>
          <xsl:if test="$Origin">
            <xsl:text disable-output-escaping="yes"> &lt;i&gt;(</xsl:text>
            <xsl:call-template name="row_address">
<xsl:with-param name="Ttype" select="''"></xsl:with-param>
<xsl:with-param name="Tname" select="''"></xsl:with-param>
<xsl:with-param name="Tcoun" select="'origin'"></xsl:with-param>
<xsl:with-param name="Tcity" select="''"></xsl:with-param>
<xsl:with-param name="Tzip"  select="''"></xsl:with-param>
<xsl:with-param name="Taddr" select="''"></xsl:with-param>
            </xsl:call-template>          
            <xsl:text disable-output-escaping="yes">)&lt;/i&gt;</xsl:text>
          </xsl:if>
        </td>
      </tr>
    <xsl:if test="$PersCode">
      <tr valign="top">
        <td align="right">personal code</td><td>:</td>
        <td>
          <xsl:value-of select="$PersCode"/><xsl:text> </xsl:text>
        </td>
      </tr>
    </xsl:if>
    <xsl:if test="($Addr.city|$Addr.zip|$Addr.address) or ($Addr.country != $Origin)">
      <tr valign="top">
        <td align="right">address</td><td>:</td>
        <td>
          <xsl:call-template name="row_address">
<xsl:with-param name="Ttype" select="''"></xsl:with-param>
<xsl:with-param name="Tname" select="''"></xsl:with-param>
<xsl:with-param name="Tcoun" select="'addr.country'"></xsl:with-param>
<xsl:with-param name="Tcity" select="'addr.city'"></xsl:with-param>
<xsl:with-param name="Tzip"  select="'addr.zip'"></xsl:with-param>
<xsl:with-param name="Taddr" select="'addr.address'"></xsl:with-param>
          </xsl:call-template>          
        </td>
      </tr>
    </xsl:if>
    </table>
  </td>
</tr>

</xsl:template>


<!-- row start - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="ManagersExecutives.Row.start">
  <xsl:choose>
    <xsl:when test="position() = 1">
      <xsl:variable name="Position"     select="../item[@type='as.executive']"/>
<td><xsl:value-of select="$Position"/></td><td>:</td>
    </xsl:when>
    <xsl:otherwise>
<td/><td> </td>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


</xsl:stylesheet>
