<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ChangesInRegistrData']">
  <xsl:variable name="title" select="'Changes In Registration Data'"/>
  <tr><td colspan="3"><strong><xsl:value-of select="$title"/></strong></td></tr>
  <xsl:apply-templates select="group"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ChangesInRegistrData']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ChangesInRegistrData.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top">
    <xsl:call-template name="ChangesInRegistrData.Row.start"/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ChangesInRegistrData.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:ChangesInRegistrData.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:ChangesInRegistrData.Row']/item[1]">

  <xsl:variable name="IsName"            select="../item[@type='is.name']"/>
  <xsl:variable name="IsLegalForm"       select="../item[@type='is.legal.form']"/>
  <xsl:variable name="IsLegalAddress"    select="../item[@type='is.legal.address']"/>
  <xsl:variable name="IsActivities"      select="../item[@type='is.activities']"/>
  <xsl:variable name="IsCapital"         select="../item[@type='is.capital']"/>
  <xsl:variable name="IsManagers"        select="../item[@type='is.managers']"/>
  <xsl:variable name="IsSignatureRights" select="../item[@type='is.signature.rights']"/>
  <xsl:variable name="IsShareholders"    select="../item[@type='is.shareholders']"/>

<tr valign="top">
  <xsl:call-template name="ChangesInRegistrData.Row.start"/>
  <td>
    <xsl:if test="$IsName = 'true'">
        <xsl:text>company's name</xsl:text>
      <xsl:if test="$IsLegalForm|$IsLegalAddress|$IsActivities|$IsCapital|$IsManagers|$IsSignatureRights|$IsShareholders">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$IsLegalForm = 'true'">
        <xsl:text>legal form</xsl:text>
      <xsl:if test="$IsLegalAddress|$IsActivities|$IsCapital|$IsManagers|$IsSignatureRights|$IsShareholders">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$IsLegalAddress = 'true'">
        <xsl:text>legal address</xsl:text>
      <xsl:if test="$IsActivities|$IsCapital|$IsManagers|$IsSignatureRights|$IsShareholders">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$IsActivities = 'true'">
        <xsl:text>activities</xsl:text>
      <xsl:if test="$IsCapital|$IsManagers|$IsSignatureRights|$IsShareholders">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$IsCapital = 'true'">
        <xsl:text>share capital</xsl:text>
      <xsl:if test="$IsManagers|$IsSignatureRights|$IsShareholders">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$IsManagers = 'true'">
        <xsl:text>managers</xsl:text>
      <xsl:if test="$IsSignatureRights|$IsShareholders">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$IsSignatureRights = 'true'">
        <xsl:text>signature rights</xsl:text>
      <xsl:if test="$IsShareholders">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:if>

    <xsl:if test="$IsShareholders = 'true'">
        <xsl:text>shareholders</xsl:text>
    </xsl:if>
  </td>
</tr>

</xsl:template>


<!-- row start - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="ChangesInRegistrData.Row.start">
  <xsl:choose>
    <xsl:when test="position() = 1">
      <xsl:variable name="Date" select="../item[@type='date']"/>
<td>
  <xsl:value-of select="$Date"/>
</td><td>:</td>
    </xsl:when>
    <xsl:otherwise>
<td/><td> </td>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


</xsl:stylesheet>
