<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:RegistrationData']">
  <xsl:variable name="title" select="'Registration Data'"/>
  <tr><td colspan="3"><strong><xsl:value-of select="$title"/></strong></td></tr>

  <xsl:apply-templates select="group|item"/>
</xsl:template>


<!-- mandatory topic n/a processing  - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:RegistrationData']/item">
  <tr valign="top">
    <td/><td>:</td><td><xsl:value-of select="."/></td>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:RegistrationData']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <tr><td colspan="3"><br/></td></tr>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:RegistrationData.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:RegistrationData.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="row_timestamps" />
  <tr><td colspan="3"><br/></td></tr>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:RegistrationData.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:RegistrationData.Row']/item[1]">

  <xsl:variable name="IsPrimary"    select="../item[@type='is.primary']"/>
  <xsl:variable name="Date"         select="../item[@type='date']"/>
  <xsl:variable name="RegnoType"    select="../item[@type='regno.type']"/>
  <xsl:variable name="Regno"        select="../item[@type='regno']"/>
  <xsl:variable name="IsBank"       select="../item[@type='is.banks']"/>
  <xsl:variable name="BankCode"     select="../item[@type='bankcode']"/>
  <xsl:variable name="RegCountry"   select="../item[@type='reg.country']"/>
  <xsl:variable name="RegCity"      select="../item[@type='reg.city']"/>
  <xsl:variable name="RegAuthority" select="../item[@type='reg.authority']"/>

<tr>
  <td>Date of registration</td><td>:</td>
  <td><xsl:value-of select="$Date"/></td>
</tr>
<tr>
  <td><xsl:value-of select="$RegnoType"/></td><td>:</td>
  <td><xsl:value-of select="$Regno"/></td>
</tr>

  <xsl:if test="$BankCode">
<tr>
  <td>Bank code</td><td>:</td>
  <td><xsl:value-of select="$BankCode"/></td>
</tr>
  </xsl:if>

  <xsl:choose>
    <xsl:when test="$RegAuthority">
<tr>
  <td>Registr. authority</td><td>:</td>
  <td><xsl:value-of select="$RegAuthority"/>
    <xsl:if test="$RegCity|$RegCountry">
      <xsl:text> (</xsl:text>
        <xsl:choose>
          <xsl:when test="not($RegCountry)">
            <xsl:value-of select="$RegCity"/>
          </xsl:when>
          <xsl:when test="not($RegCity)">
            <xsl:value-of select="$RegCountry"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$RegCity"/>, <xsl:value-of select="$RegCountry"/>
          </xsl:otherwise>
        </xsl:choose>
      <xsl:text>)</xsl:text>
    </xsl:if>
  </td>
</tr>
    </xsl:when>
    <xsl:when test="$RegCity|$RegCountry">
<tr>
  <td>Registration place</td><td>:</td>
  <td>
        <xsl:choose>
          <xsl:when test="not($RegCountry)">
            <xsl:value-of select="$RegCity"/>
          </xsl:when>
          <xsl:when test="not($RegCity)">
            <xsl:value-of select="$RegCountry"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$RegCity"/>, <xsl:value-of select="$RegCountry"/>
          </xsl:otherwise>
        </xsl:choose>
  </td>
</tr>
    </xsl:when>
    <xsl:otherwise/>
  </xsl:choose>

</xsl:template>


</xsl:stylesheet>
