<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Participation']">
  <xsl:variable name="title" select="'Participation'"/>
  <tr><td colspan="3"><strong><xsl:value-of select="$title"/></strong></td></tr>

  <xsl:apply-templates select="group|item"/>
</xsl:template>


<!-- mandatory topic n/a processing  - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Participation']/item">
  <tr valign="top">
    <td/><td>:</td><td><xsl:value-of select="."/></td>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- topic-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Participation']/group[@type='cr:TopicComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Participation.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top">
    <xsl:call-template name="Participation.Row.start"/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


<!-- row processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Participation.Row']">
  <xsl:apply-templates select="group|item"/>
  <xsl:call-template name="row_timestamps" />
  <xsl:call-template name="tr_empty"/>
</xsl:template>


<!-- row-item processing  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Participation.Row']/item[position()>1]" />

<xsl:template match="group[@type='cr:Participation.Row']/item[1]">

  <xsl:variable name="IsPresence"      select="../item[@type='is.presence']"/>
  <xsl:variable name="Name"            select="../item[@type='name']"/>
  <xsl:variable name="Igkno"           select="../item[@type='igkno']"/>
  <xsl:variable name="Origin"          select="../item[@type='origin']"/>
  <xsl:variable name="Regno"           select="../item[@type='regno']"/>
  <xsl:variable name="ShareProcent"    select="../item[@type='share.procent']"/>
  <xsl:variable name="IsShareUltimate" select="../item[@type='is.share.ultimate']"/>
  <xsl:variable name="IsShareEst"      select="../item[@type='is.share.est']"/>
  <xsl:variable name="Value"           select="../item[@type='value']"/>
  <xsl:variable name="Currency"        select="../item[@type='currency']"/>
  <xsl:variable name="Addr.country"    select="../item[@type='addr.country']"/>
  <xsl:variable name="Addr.city"       select="../item[@type='addr.city']"/>
  <xsl:variable name="Addr.zip"        select="../item[@type='addr.zip']"/>
  <xsl:variable name="Addr.address"    select="../item[@type='addr.address']"/>

<tr valign="top">
  <xsl:call-template name="Participation.Row.start"/>
  <td>
    <xsl:choose>
      <xsl:when test="$IsPresence = 'true'">
        <xsl:text disable-output-escaping="yes">yes &lt;br/&gt;</xsl:text>
      </xsl:when>
      <xsl:when test="$IsPresence = 'false'">
        <xsl:text disable-output-escaping="yes">none &lt;br/&gt;</xsl:text>
      </xsl:when>
      <xsl:otherwise/>
    </xsl:choose>

    <table cellSpacing="0" cellPadding="0" width="95%">
      <colgroup>
<col width="145"/>
<col width="10"/>
<col width="255"/>
<col width="65" align="right"/>
<col width="25" align="right"/>
      </colgroup>
      <tr valign="top">
        <td colspan="3">
          <xsl:value-of select="$Name"/>
          <xsl:if test="$Origin">
            <xsl:text disable-output-escaping="yes"> &lt;i&gt;(</xsl:text>
            <xsl:call-template name="row_address">
<xsl:with-param name="Ttype" select="''"></xsl:with-param>
<xsl:with-param name="Tname" select="''"></xsl:with-param>
<xsl:with-param name="Tcoun" select="'origin'"></xsl:with-param>
<xsl:with-param name="Tcity" select="''"></xsl:with-param>
<xsl:with-param name="Tzip"  select="''"></xsl:with-param>
<xsl:with-param name="Taddr" select="''"></xsl:with-param>
            </xsl:call-template>          
            <xsl:text disable-output-escaping="yes">)&lt;/i&gt;</xsl:text>
          </xsl:if>
        </td>
        <td>
          <xsl:choose>
            <xsl:when test="$IsPresence" />
            <xsl:when test="$ShareProcent">
              <xsl:value-of select="$ShareProcent"/><xsl:text> %</xsl:text>
            </xsl:when>
            <xsl:when test="$IsShareUltimate = 'true'">
              <xsl:text>ultimate</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>n/a %</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </td>
        <td>
          <xsl:if test="$IsShareEst = 'true'">
            <xsl:text>[E]</xsl:text>
          </xsl:if>
        </td>
      </tr>
    <xsl:if test="$Value">
      <tr valign="top">
        <td align="right">share's book value</td><td>:</td>
        <td>
          <xsl:value-of select="$Value"/><xsl:text> </xsl:text>
          <xsl:value-of select="$Currency"/>
          <xsl:if test="$IsShareEst='true'">
            <xsl:text> [E]</xsl:text>
          </xsl:if>
        </td>
      </tr>
    </xsl:if>
    <xsl:if test="$Regno">
      <tr valign="top">
        <td align="right">registr. number</td><td>:</td>
        <td>
          <xsl:value-of select="$Regno"/><xsl:text> </xsl:text>
        </td>
      </tr>
    </xsl:if>
    <xsl:if test="($Addr.city|$Addr.zip|$Addr.address) or ($Addr.country != $Origin)">
      <tr valign="top">
        <td align="right">address</td><td>:</td>
        <td>
          <xsl:call-template name="row_address">
<xsl:with-param name="Ttype" select="''"></xsl:with-param>
<xsl:with-param name="Tname" select="''"></xsl:with-param>
<xsl:with-param name="Tcoun" select="'addr.country'"></xsl:with-param>
<xsl:with-param name="Tcity" select="'addr.city'"></xsl:with-param>
<xsl:with-param name="Tzip"  select="'addr.zip'"></xsl:with-param>
<xsl:with-param name="Taddr" select="'addr.address'"></xsl:with-param>
          </xsl:call-template>          
        </td>
      </tr>
    </xsl:if>
    </table>
  </td>
</tr>

</xsl:template>


<!-- row start - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template name="Participation.Row.start">
  <td/>
  <td>
  <xsl:choose>
    <xsl:when test="position() = 1">
<xsl:text>:</xsl:text>
    </xsl:when>
    <xsl:otherwise>
<xsl:text> </xsl:text>
    </xsl:otherwise>
  </xsl:choose>
  </td>
</xsl:template>


</xsl:stylesheet>
