<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" indent="yes" encoding="UTF-8"/>
  <xsl:strip-space elements="*" />

<!-- topic processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Summary']">

  <xsl:variable name="LegalForm"   select="item[@type='legal.form']"/>
  <xsl:variable name="Established" select="item[@type='creation.date']"/>
  <xsl:variable name="Employees"   select="item[@type='employees']"/>
  <xsl:variable name="Defaults"    select="item[@type='is.defaults']"/>
  <xsl:variable name="Remarks"     select="item[@type='is.remarks.on.payments']"/>

  <xsl:variable name="NetSales"    select="group[@type='financial.stmts']/item[@type='net sales']"/>
  <xsl:variable name="NsDegree"    select="group[@type='financial.stmts']/item[@type='degree']"/>
  <xsl:variable name="NsCurrency"  select="group[@type='financial.stmts']/item[@type='currency']"/>
  <xsl:variable name="NsMonths"    select="group[@type='financial.stmts']/item[@type='months']"/>
  <xsl:variable name="NsDate"      select="group[@type='financial.stmts']/item[@type='revision']"/>

<tr valign="top"><td colspan="3"><hr/>
<center><strong> S U M M A R Y </strong></center>
<br/>
<strong>Legal Form</strong><xsl:text> : </xsl:text>
  <xsl:call-template name="PutData">
    <xsl:with-param name="Value" select="$LegalForm"/>
    <xsl:with-param name="Mandatory" select="'true'" />
  </xsl:call-template>
<br/>
<br/>
<table cellSpacing="0" cellPadding="0" width="100%">
  <tr valign="top">
    <td><strong>Established</strong><xsl:text> : </xsl:text>
      <xsl:call-template name="PutData">
        <xsl:with-param name="Value" select="$Established"/>
        <xsl:with-param name="Mandatory" select="'true'" />
      </xsl:call-template>
    </td>
    <td><strong>Employees</strong><xsl:text> : </xsl:text>
      <xsl:call-template name="PutData">
        <xsl:with-param name="Value" select="$Employees"/>
        <xsl:with-param name="Mandatory" select="'true'" />
      </xsl:call-template>
    </td>
    <td><strong>Defaults registered</strong><xsl:text> : </xsl:text>
  <xsl:choose>
    <xsl:when test="$Defaults='true'"> yes </xsl:when>
    <xsl:when test="$Defaults='false'"> none </xsl:when>
    <xsl:otherwise> n/a </xsl:otherwise>
  </xsl:choose>
<br/>
<strong>Remarks on payments</strong><xsl:text> : </xsl:text>
  <xsl:choose>
    <xsl:when test="$Remarks='true'"> yes </xsl:when>
    <xsl:when test="$Remarks='false'"> none </xsl:when>
    <xsl:otherwise> n/a </xsl:otherwise>
  </xsl:choose>
    </td>
  </tr>
</table>
<br/>

<strong>Net Sales</strong><xsl:text> : </xsl:text>
      <xsl:call-template name="PutData">
        <xsl:with-param name="Value" select="$NetSales"/>
        <xsl:with-param name="Mandatory" select="'true'" />
      </xsl:call-template>

<xsl:if test="$NetSales != ''">
  <xsl:choose>
    <xsl:when test="$NsDegree='3'"> th </xsl:when>
    <xsl:when test="$NsDegree='6'"> mio </xsl:when>
    <xsl:otherwise/>
  </xsl:choose>
 <xsl:text> </xsl:text>
 <xsl:value-of select="$NsCurrency"/>
 <xsl:text> </xsl:text>
<i>( for
 <xsl:text> </xsl:text>
 <xsl:value-of select="$NsMonths"/> 
 <xsl:text> </xsl:text>
 months, ended
 <xsl:text> </xsl:text>
 <xsl:value-of select="$NsDate"/> 
 <xsl:text> </xsl:text>
)</i>
</xsl:if>

<br/></td></tr>
<tr valign="top"><td colspan="3"><br/></td></tr>

  <xsl:apply-templates select="group[@type='cr:Credit Opinion']"/>

<tr valign="top"><td colspan="3"><br/></td></tr>
<tr valign="top"><td colspan="3"><hr/></td></tr>
<tr valign="top"><td colspan="3"><br/></td></tr>

</xsl:template>


<!-- CreditOpinion processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Summary']/group[@type='cr:Credit Opinion']">
  <xsl:apply-templates select="group"/>
</xsl:template>

<!-- CreditOpinion.row processing - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Summary']/group[@type='cr:Credit Opinion']/group[@type='cr:Credit Opinion.Row']">

  <xsl:variable name="CrRating"      select="item[@type='rating']"/>
  <xsl:variable name="CrDescription" select="item[@type='description']"/>
  <xsl:variable name="CrAmount"      select="item[@type='amount']"/>
  <xsl:variable name="CrCurrency"    select="item[@type='currency']"/>
  <xsl:variable name="CrIsMaximum"   select="item[@type='is.maximum']"/>
  <xsl:variable name="CrComments"    select="item[@type='comments']"/>
  <xsl:variable name="CrConclusion"  select="item[@type='conclusion']"/>

<tr valign="top"><td><strong>Credit Opinion</strong></td></tr>
<tr valign="top">
  <td>Credit rating</td>
  <td>:</td>
  <td>[<xsl:value-of select="$CrRating"/>]
       <xsl:value-of select="$CrDescription"/>
  </td>
</tr>
<xsl:if test="$CrAmount">
<tr valign="top"><td>Credit value</td><td>:</td><td>
  <xsl:choose>
    <xsl:when test="$CrIsMaximum='true'"> Maximum credit </xsl:when>
    <xsl:otherwise> Credit </xsl:otherwise>
  </xsl:choose>
 amount of <xsl:value-of select="$CrAmount"/>
 <xsl:text> </xsl:text>
 <xsl:value-of select="$CrCurrency"/>
 <xsl:text> is advised.</xsl:text>
</td></tr>
</xsl:if>

<xsl:if test="$CrComments">
<tr valign="top"><td>Comments</td><td>:</td><td><xsl:value-of select="$CrComments"/></td></tr>
</xsl:if>

<tr valign="top"><td>Conclusion</td><td>:</td><td><xsl:value-of select="$CrConclusion"/></td></tr>

  <xsl:apply-templates select="group"/>

</xsl:template>

<!-- row-comment processing - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

<xsl:template match="group[@type='cr:Summary']/group[@type='cr:Credit Opinion']/group[@type='cr:Credit Opinion.Row']/group[@type='cr:RowComments.Row']">
  <tr valign="top"><td/><td/>
    <xsl:call-template name="td_comment"/>
  </tr>
</xsl:template>


</xsl:stylesheet>
